"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const ecs = require("../src/ecs-deploy");
const ecs_deploy_1 = require("../src/ecs-deploy");
console.log(`[WARNING] The tests are run against REAL services.
Make sure that the service described by the config is something dispensable.\n`);
let config;
try {
    config = require('./config.test');
}
catch (err) {
    console.log(`You need to create a "config.test.json" file in the test folder in order to run the integation tests
(see "config.test.json.example" for reference)`);
}
describe('updateTag', () => {
    it('should replace tag', () => __awaiter(this, void 0, void 0, function* () {
        // Arrange
        const tag = '874_672af8';
        const newTag = 'baz';
        const base = '366857391347.dkr.ecr.eu-west-1.amazonaws.com/charles';
        // Act
        const image = ecs_deploy_1.updateTag(`${base}:${tag}`, newTag);
        // Assert
        chai_1.expect(image).to.eq(`${base}:${newTag}`);
    }));
    it('should insert tag', () => __awaiter(this, void 0, void 0, function* () {
        // Arrange
        const newTag = 'baz';
        const base = 'aaa.bb.c/bar';
        // Act
        const image = ecs_deploy_1.updateTag(base, newTag);
        // Assert
        chai_1.expect(image).to.eq(`${base}:${newTag}`);
    }));
});
if (config) {
    describe('ecs-updater', () => {
        it('can re-register a taskDefinition', () => __awaiter(this, void 0, void 0, function* () {
            const previous = yield ecs.getRegisteredTaskDefinition(config);
            const current = yield ecs.registerTaskDefinition(config, previous);
            chai_1.expect(current.revision).to.be.gt(previous.revision);
        }));
        it('can restart a service', () => __awaiter(this, void 0, void 0, function* () {
            const { current, previous } = yield ecs.restart(config);
            yield ecs.syncRevision(config, current);
            chai_1.expect(current.revision).to.exist;
            chai_1.expect(previous.revision).to.exist;
            chai_1.expect(current.revision).to.be.gt(previous.revision);
        }));
        it('can retrieve a taskDefinition from S3', () => __awaiter(this, void 0, void 0, function* () {
            const response = yield ecs.getS3TaskDefinition(config);
            chai_1.expect(response).to.exist;
            chai_1.expect(response.family).to.exist;
        }));
        it('can retrieve the image tag from S3', () => __awaiter(this, void 0, void 0, function* () {
            const response = yield ecs.getS3ImageTag(config);
            chai_1.expect(response).to.exist;
        }));
    });
}
//# sourceMappingURL=tests.js.map